==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webdav/inc/server.php <==
<?php
// Hlavn rmec aplikace WebDAV serveru
// WebDAV server application framework

error_reporting(E_ALL ^E_WARNING ^E_NOTICE);
include_once 'caldav.php';
include_once 'function.php';

//************************************************************
// Hlavn rmec aplikace WebDAV serveru
// WebDAV server application framework
//************************************************************

//Identifikace session
//Identification of session
$start_session=true;

//Poslal nm klient cookie?
//Didn't client send cookie?
if (!$_COOKIE[session_name()]) 
{
  $authorization=$_SERVER['HTTP_AUTHORIZATION'];

  if ($authorization) 
    
    //Obsluha session_id
    //Handle session_id  
    session_id(md5($_SERVER['HTTP_AUTHORIZATION'].$_SERVER['HTTP_USER_AGENT'].$_SERVER['REMOTE_ADDR'].$_SERVER['REQUEST_URI']));
  else
    $start_session=false;
}
else
{
	$session_id=md5($_SERVER['HTTP_AUTHORIZATION'].$_SERVER['HTTP_USER_AGENT'].$_SERVER['REMOTE_ADDR'].$_SERVER['REQUEST_URI']);
	
	if (session_id()!=$session_id)
	  session_id($session_id);
}

if ($start_session) 
  session_start();

//Mme novou session?
//Have we new session?
if (!$_SESSION['caldav_session'])
{
  server_config();
  $_SESSION['caldav_session']=new caldav_session();
}
else
	//Nejsme ji pihleni?
	//Isn't we logged on already?
	if (!$_SESSION['caldav_session']->user_logged_on())
  {
    do_log('!!! Session recreate !!!',2); 
    
    unset($_SESSION['caldav_session']);
    $_SESSION['caldav_session']=new caldav_session();
  }

//Je CalDAV vypnut?
//Is CalDAV disabled?
if ($_SESSION['Disabled'])
{
  //Uvolnn session
  //Free session
  if ($start_session)
  {
    session_unset();
    session_destroy();
  }
  
  header('HTTP/1.1 403 Forbidden');
  exit;
}  

//Obsluha pijet pkazu a vytvoen odpovdi
//Handle requested command and create response
$_SESSION['caldav_session']->handle_request();
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webdav/inc/server.php <==
<?php
// WebDAV server application framework

error_reporting(E_ALL ^E_WARNING ^E_NOTICE);
include_once 'caldav.php';
include_once 'function.php';

//************************************************************
// WebDAV server application framework
//************************************************************

function create_session_id()
{
  $request_uri=$_SERVER['REQUEST_URI'];
  $fields=explode('/',$request_uri);

	if ($fields[2]=='users')
	  $email=$fields[3];
	else
	  $email=$fields[2];

  // Create new session_id based on the login name, browser, remote address and uri
  return md5($_SERVER['HTTP_AUTHORIZATION'].$_SERVER['HTTP_USER_AGENT'].$_SERVER['REMOTE_ADDR'].$email);
}

//Identification of session
$start_session=true;
$authorization=$_SERVER['HTTP_AUTHORIZATION'];

//Didn't client send cookie?
if (!$_COOKIE[session_name()]) 
{
  if ($authorization) 
    
    //Handle session_id  
    session_id(create_session_id());
  else
    $start_session=false;
}
else
	if ($authorization)
	{
		$session_id=create_session_id();
	
	  if (session_id()!=$session_id)
	    session_id($session_id);
  }

if ($start_session) 
  session_start();

//Have we new session?
if (!$_SESSION['caldav_session'])
{
  server_config();
  $_SESSION['caldav_session']=new caldav_session();
}
else
	//Isn't we logged on already?
	if (!$_SESSION['caldav_session']->user_logged_on())
  {
    do_log('!!! Session recreate !!!',2); 
    
    unset($_SESSION['caldav_session']);
    $_SESSION['caldav_session']=new caldav_session();
  }

//Is CalDAV disabled?
if ($_SESSION['Disabled'])
{
  //Free session
  if ($start_session)
  {
    session_unset();
    session_destroy();
  }
  
  header(($_SERVER['HTTPS']=='ON'?'HTTPS':'HTTP').'/1.1 403 Forbidden');
  exit;
}  

//Handle requested command and create response
$_SESSION['caldav_session']->handle_request();
?>
